@@ -114,7 +114,7 @@ def redeem_voucher(reference_code):
                 if redeem_datetime_in_gmt:
                     redeem_datetime    =  redeem_datetime_in_gmt - timedelta(hours=merchant_acct.gmt_hour)
                     
-                    now                  = datetime.now() - timedelta(hours=int(conf.SERVER_DATETIME_GMT))
+                    now                  = datetime.utcnow()
                     if redeem_datetime > now:
                         return create_rest_message('Redeem datetime cannot be future', status_code=StatusCode.BAD_REQUEST)
                 
